import React from 'react';
import { string, bool, shape, array, oneOfType } from 'prop-types';

import { mergeClasses } from '@magento/venia-ui/lib/classify';
import defaultClasses from './highlightAll.css';
import Carousel from './Carousel';
import { resourceUrl } from '@swissup/pwa-highlight/lib/talons/HighlightContent';

const toHTML = str => ({ __html: str });

const HighlightAll = props => {

    const {
        enabled,
        nodeClasses,
        title : {
            html,
            img: {
                src: titleImgSrc,
                width: titleImgWidth,
                height: titleImgHeight
            }
        },
        carousel
    } = props;

    if (enabled === false) {
        return '';
    }

    const titleHtml = toHTML(html.replace(titleImgSrc, resourceUrl(
        titleImgSrc, {
            width: titleImgWidth,
            height: titleImgHeight,
            fit: 'cover'
        }
    )).replace(' src="', ` width=${titleImgWidth} height=${titleImgHeight} src="`)
    );

    const classes = mergeClasses(defaultClasses, props.classes);

    const listNodeClasses = nodeClasses.map(cssClass => {
        return (classes[cssClass] ? `${classes[cssClass]}` : '');
    }).join(' ');
    const rootClasses = `${classes.root} ${listNodeClasses}`;

    return (
        <div className={rootClasses}>
            <div className={classes.title} dangerouslySetInnerHTML={titleHtml} />
            <div className={classes.content}>
                <Carousel {...carousel} />
            </div>
        </div>
    )
};

HighlightAll.propTypes = {
    classes: shape({
        title: string,
        content: string,
        root: string
    }),
    enabled: bool.isRequired,
    nodeClasses: array.isRequired,
    title: shape({
        html: string.isRequired,
        img: shape({
            src: oneOfType([bool, string]),
        })
    })
};

export default HighlightAll;